@@ -383,15 +383,15 @@ class AlbToFargateProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new ALB and any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. Default: - none
         '''
         if isinstance(alb_logging_bucket_props, dict):
-            alb_logging_bucket_props = BucketProps(**alb_logging_bucket_props)
+            alb_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**alb_logging_bucket_props)
         if isinstance(cluster_props, dict):
-            cluster_props = ClusterProps(**cluster_props)
+            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
         if isinstance(rule_props, dict):
-            rule_props = AddRuleProps(**rule_props)
+            rule_props = aws_cdk.aws_elasticloadbalancingv2.AddRuleProps(**rule_props)
         if isinstance(target_group_props, dict):
-            target_group_props = ApplicationTargetGroupProps(**target_group_props)
+            target_group_props = aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps(**target_group_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(AlbToFargateProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
